@@ -4,7 +4,9 @@ OC.L10N.register(
     "All contacts" : "كل الجهات",
     "Details" : "التفاصيل",
     "Contacts" : "جهات الاتصال",
+    "Copy to full name" : "انسخ إلى الإسم الكامل",
     "Upload a new picture" : "تحميل صورة جديدة",
+    "Choose from Files" : "اختر من الملفات",
     "Download picture" : "تنزيل الصورة",
     "Delete picture" : "حذف الصورة",
     "Invalid image" : "الصورة غير صالحة",
