@@ -1,10 +1,9 @@
 OC.L10N.register(
     "contacts",
     {
-    "Contacts" : "Əlaqələr",
     "Details" : "Detallar",
+    "Contacts" : "Əlaqələr",
     "Invalid image" : "Yalnış şəkil",
-    "Loading" : "Loading",
     "Name" : "Ad",
     "Title" : "Başlıq",
     "Download" : "Yüklə",
@@ -17,6 +16,8 @@ OC.L10N.register(
     "Copy link" : "linki nüsxələ",
     "can edit" : "dəyişmək olar",
     "Not grouped" : "Qruplaşdırılmayıb",
+    "Close" : "Bağla",
+    "Import" : "Əlavə et",
     "Notes" : "Qeydlər",
     "Location" : "Yerləşdiyiniz ünvan",
     "Home" : "Ev",
