@@ -1,11 +1,10 @@
 OC.L10N.register(
     "contacts",
     {
-    "Contacts" : "Contactos",
     "All contacts" : "Tote contactos",
     "Details" : "Detalios",
+    "Contacts" : "Contactos",
     "Invalid image" : "Imagine invalide",
-    "Loading" : "Loading",
     "Name" : "Nomine",
     "Title" : "Titulo",
     "Download" : "Discargar",
@@ -22,7 +21,10 @@ OC.L10N.register(
     "First name" : "Prime nomine",
     "Last name" : "Ultime nomine",
     "Display name" : "Monstrar nomine",
+    "Group name" : "Nomine del gruppo",
     "Not grouped" : "Non gruppate",
+    "Close" : "Clauder",
+    "Import" : "Importar",
     "Nickname" : "Pseudonymo",
     "Detailed name" : "Nomine detaliate",
     "Additional names" : "Nomines additional",
