@@ -1,10 +1,9 @@
 OC.L10N.register(
     "contacts",
     {
-    "Contacts" : "ទំនាក់​ទំនង",
     "Details" : "ព័ត៌មាន​លម្អិត",
+    "Contacts" : "ទំនាក់​ទំនង",
     "Invalid image" : "រូបភាព​មិន​ត្រឹម​ត្រូវ",
-    "Loading" : "Loading",
     "Name" : "ឈ្មោះ",
     "Title" : "ចំណងជើង",
     "Download" : "ទាញយក",
@@ -16,6 +15,8 @@ OC.L10N.register(
     "Disabled" : "បាន​បិទ",
     "can edit" : "អាច​កែប្រែ",
     "Not grouped" : "គ្មាន​ក្រុម",
+    "Close" : "បិទ",
+    "Import" : "នាំយកចូល",
     "Notes" : "កំណត់​ចំណាំ",
     "Location" : "ទីតាំង",
     "Work" : "ធ្វើការ",
