@@ -7,16 +7,21 @@ OC.L10N.register(
     "A contacts app for Nextcloud" : "Nextcloud 연락처 앱",
     "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud 연락처 앱은 Nextcloud CardDAV 서버 사용자 인터페이스입니다. 다양한 장치의 주소록을 Nextcloud와 동기화하고 온라인으로 편집하십시오.\n\n* 🚀 **다른 Nextcloud 앱과 통합!** 현재 메일과 달력 앱과 통합되어 있으며 더 많은 앱을 지원할 예정입니다.\n* 🎉 **생일을 잊지 마세요!** Nextcloud 달력과 생일 및 반복되는 행사를 동기화할 수 있습니다.\n* 👥 **주소록을 공유하세요!** 친구나 동료와 주소록을 공유하고 싶으신가요? 문제 없습니다!\n* 🙈 **바퀴를 재발명하지 않습니다!** SabreDAV 라이브러리를 사용합니다.",
     "Copy to full name" : "전체 이름으로 복사",
+    "Allow updating avatars from social media" : "소셜 네트워크에서 아바타 업데이트를 허용",
     "Add new property" : "새 속성 추가",
     "Choose property type" : "속성 종류 선택",
     "Upload a new picture" : "새 그림 업로드",
-    "Choose from files" : "파일에서 선택",
+    "Get from " : "가져오기 - ",
     "Download picture" : "그림 다운로드",
     "Delete picture" : "그림 삭제",
+    "Choose from files" : "파일에서 선택",
     "Invalid image" : "잘못된 사진",
     "Image is too big (max 1MB)." : "그림이 너무 큽니다(최대 1MB).",
     "Pick an avatar" : "아바타 선택",
     "Error while processing the picture." : "그림을 처리하는 중 오류가 발생했습니다.",
+    "Avatar downloaded from social network" : "소셜 네트워크에서 아바타가 다운로드 되었습니다",
+    "Avatar already up to date" : "아바타가 이미 업데이트 되었습니다",
+    "Avatar download failed" : "아바타 다운로드 실패",
     "No contact selected" : "선택한 연락처 없음",
     "Select a contact on the list to begin" : "목록에서 연락처를 선택하여 시작하십시오",
     "Name" : "이름",
@@ -38,6 +43,7 @@ OC.L10N.register(
     "Unable to retrieve the contact from the server, please check your network connection." : "연락처를 가져올 수 없습니다. 네트워크 연결을 확인하세요.",
     "An error occurred while trying to move the contact" : "연락처를 이동하는 중 오류 발생",
     "An error occurred while trying to copy the contact" : "연락처를 복사하는 중 오류 발생",
+    "Search {types}" : "{types} 검색",
     "Loading …" : "불러오는 중 …",
     "List is empty" : "목록이 비어 있음",
     "No results" : "결과 없음",
@@ -72,9 +78,13 @@ OC.L10N.register(
     "An error occurred, unable to create the address book" : "오류가 발생하여 주소록을 생성할 수 없습니다.",
     "First name" : "이름",
     "Last name" : "성",
+    "Phonetic first name" : "이름 표음",
+    "Phonetic last name" : "성 표음",
     "Display name" : "표시 이름",
     "Sort by {sorting}" : "{sorting}(으)로 정렬",
+    "(refreshed once per week)" : "(주 1회 새로고침)",
     "Add contacts" : "연락처 추가",
+    "+ New group" : "+ 새 그룹",
     "Create a new group" : "새 그룹 생성",
     "Group name" : "그룹 이름",
     "Loading contacts …" : "연락처 불러오는 중…",
@@ -140,6 +150,7 @@ OC.L10N.register(
     "Colleague" : "동료",
     "Manager" : "관리자",
     "Assistant" : "비서",
+    "Related contacts" : "관련된 연락처",
     "Contact" : "연락처",
     "Agent" : "에이전트",
     "Emergency" : "긴급 연락처",
