@@ -1,11 +1,10 @@
 OC.L10N.register(
     "contacts",
     {
-    "Contacts" : "Харилцагчид",
     "All contacts" : "Бүх харилцагчид",
     "Details" : "Дэлгэрэнгүй",
+    "Contacts" : "Харилцагчид",
     "Invalid image" : "буруу зураг",
-    "Loading" : "Loading",
     "Name" : "Нэр",
     "Title" : "Цол/Албан тушаал",
     "Download" : "Татаж авах",
@@ -24,7 +23,10 @@ OC.L10N.register(
     "First name" : "Нэр",
     "Last name" : "Овог",
     "Display name" : "Харагдах нэр",
+    "Group name" : "Бүлгийн нэр",
     "Not grouped" : "Багт ороогүй",
+    "Close" : "Хаах",
+    "Import" : "Импорт",
     "Nickname" : "Товч нэр",
     "Detailed name" : "Дэлгэрэнгүй нэр",
     "Additional names" : "Нэмэлт нэрүүд",
