@@ -1,10 +1,9 @@
 OC.L10N.register(
     "contacts",
     {
-    "Contacts" : "Kontaktar",
     "Details" : "Detaljar",
+    "Contacts" : "Kontaktar",
     "Invalid image" : "Ugyldig bilete",
-    "Loading" : "Loading",
     "Name" : "Namn",
     "Title" : "Tittel",
     "Download" : "Last ned",
@@ -16,7 +15,10 @@ OC.L10N.register(
     "can edit" : "kan endra",
     "First name" : "Fornamn",
     "Last name" : "Etternamn",
+    "Group name" : "Gruppenamn",
     "Not grouped" : "Ikkje gruppert",
+    "Close" : "Lukk",
+    "Import" : "Importer",
     "Nickname" : "Kallenamn",
     "Additional names" : "Andre namn",
     "Notes" : "Notat",
